@@ -1,6 +1,6 @@
 #! /bin/false
 
-# Copyright (C) 2021-2025 Guido Flohr <guido.flohr@cantanea.com>,
+# Copyright (C) 2021 Guido Flohr <guido.flohr@cantanea.com>,
 # all rights reserved.
 
 # This program is free software. It comes without any warranty, to
@@ -10,7 +10,7 @@
 # http://www.wtfpl.net/ for more details.
 
 package Chess::Plisco::Engine::InputWatcher;
-$Chess::Plisco::Engine::InputWatcher::VERSION = 'v0.8.0';
+$Chess::Plisco::Engine::InputWatcher::VERSION = '0.1';
 use strict;
 
 use IO::Select;
@@ -22,20 +22,11 @@ sub new {
 	my $sel = IO::Select->new($fh);
 
 	bless {
-		__handle => $fh,
 		__sel => $sel,
 		__input => '',
 	}, $class;
 }
 
-sub setBatchMode {
-	my ($self, $mode) = @_;
-
-	$self->{__batch_mode} = $mode;
-
-	return $self;
-}
-
 sub onInput {
 	my ($self, $cb) = @_;
 
@@ -51,21 +42,14 @@ sub onEof {
 }
 
 sub check {
-	my ($self, $tree) = @_;
+	my ($self, $timeout) = @_;
 
-	return if $self->{__batch_mode};
-
-	if (delete $self->{__stop_requested}) {
-		$tree->{stop_requested} = 1;
-	}
-
-	while (my @ready = $self->{__sel}->can_read(0)) {
+	while (my @ready = $self->{__sel}->can_read($timeout)) {
 		foreach my $fh (@ready) {
 			my $offset = length $self->{__input};
-			my $bytes = $fh->sysread($self->{__input}, 1, $offset);
+			my $bytes = $fh->sysread($self->{__input}, 2, $offset);
 			if (!$bytes) {
 				$self->{__on_eof}->() if $self->{__on_eof};
-				return;
 			} elsif ($self->{__input} =~ s/^(.*?)\n//) {
 				$self->{__on_input}->($1) if $self->{__on_input};
 			}
@@ -73,10 +57,4 @@ sub check {
 	}
 }
 
-sub requestStop {
-	my ($self) = @_;
-
-	$self->{__stop_requested} = 1;
-}
-
 1;
