@@ -1,6 +1,6 @@
 #! /bin/false
 
-# Copyright (C) 2021-2025 Guido Flohr <guido.flohr@cantanea.com>,
+# Copyright (C) 2021 Guido Flohr <guido.flohr@cantanea.com>,
 # all rights reserved.
 
 # This program is free software. It comes without any warranty, to
@@ -10,7 +10,7 @@
 # http://www.wtfpl.net/ for more details.
 
 package Chess::Plisco::Macro;
-$Chess::Plisco::Macro::VERSION = 'v0.8.0';
+$Chess::Plisco::Macro::VERSION = '0.1';
 use strict;
 
 use Filter::Util::Call;
@@ -55,8 +55,6 @@ _define cp_pos_signature => '$p', '$p->[CP_POS_SIGNATURE]';
 sub cp_pos_signature {}
 _define cp_pos_info => '$p', '$p->[CP_POS_INFO]';
 sub cp_pos_info {}
-_define cp_pos_reversible_clock => '$p', '$p->[CP_POS_REVERSIBLE_CLOCK]';
-sub cp_pos_reversible_clock {}
 
 _define cp_pos_info_castling_rights => '$i', '$i & 0xf';
 sub cp_pos_info_castling_rights {}
@@ -183,13 +181,8 @@ _define cp_move_set_color => '$m', '$c',
 sub cp_move_set_captured {}
 _define cp_move_coordinate_notation => '$m', 'cp_shift_to_square(cp_move_from $m) . cp_shift_to_square(cp_move_to $m) . CP_PIECE_CHARS->[CP_BLACK]->[cp_move_promote $m]';
 sub cp_move_coordinate_notation {}
-_define cp_move_significant => '$m', '($m & 0x7fff)';
-sub cp_move_significant {}
-_define cp_move_equivalent => '$m1', '$m2',
-		'(cp_move_significant($m1) == cp_move_significant($m2))';
+_define cp_move_equivalent => '$m1', '$m2', '(($m1 & 0x7fff) == ($m2 & 0x7fff))';
 sub cp_move_equivalent {}
-_define cp_move_capture_or_promotion => '$m', '($m & 0x1c7000)';
-sub cp_move_capture_or_promotion {}
 
 # Bitboard macros.
 _define cp_bitboard_popcount => '$b', '$c',
@@ -206,8 +199,6 @@ _define_from_file cp_bitboard_count_trailing_zbits => '$bb', 'countTrailingZbits
 sub cp_bitboard_count_trailing_zbits {}
 _define cp_bitboard_clear_least_set => '$bb', '(($bb) & (($bb) - 1))';
 sub cp_bitboard_clear_least_set {}
-_define cp_bitboard_more_than_one_set => '$bb', '($bb && ($bb & ($bb - 1)))';
-sub cp_bitboard_more_than_one_set {}
 
 # Magic moves.
 _define cp_mm_bmagic => '$s', '$o',
